@@ -17,12 +17,26 @@ def ensure_slash_suffix(s: str):
 
 
 def ensure_no_slash_suffix(s: str):
-    if s.endswith(path_sep):
-        s = s[:-1]
-    return s
+    return s.rstrip(path_sep)
 
 
-def git(command='status', work_tree='.', git_dir=None):
+def _build_git_command(command: str = "status", work_tree=".", git_dir=None):
+    if command.startswith("git "):
+        warn(
+            "You don't need to start your command with 'git '. I know it's a git command. Removing that prefix"
+        )
+        command = command[len("git ") :]
+    work_tree = os.path.abspath(os.path.expanduser(work_tree))
+    if git_dir is None:
+        git_dir = os.path.join(work_tree, ".git")
+    assert os.path.isdir(git_dir), f"Didn't find the git_dir: {git_dir}"
+    git_dir = ensure_no_slash_suffix(git_dir)
+    if not git_dir.endswith(".git"):
+        warn(f"git_dir doesn't end with `.git`: {git_dir}")
+    return f'git --git-dir="{git_dir}" --work-tree="{work_tree}" {command}'
+
+
+def git(command: str = "status", work_tree=".", git_dir=None):
     """Launch git commands.
 
     :param command: git command (e.g. 'status', 'branch', 'commit -m "blah"', 'push', etc.)
@@ -37,20 +51,8 @@ def git(command='status', work_tree='.', git_dir=None):
     git --git-dir=/path/to/my/directory/.git/ --work-tree=/path/to/my/directory/ commit -m 'something'
 
     """
-    if command.startswith('git '):
-        warn(
-            "You don't need to start your command with 'git '. I know it's a git command. Removing that prefix"
-        )
-        command = command[len('git ') :]
-    work_tree = os.path.abspath(os.path.expanduser(work_tree))
-    if git_dir is None:
-        git_dir = os.path.join(work_tree, '.git')
-    assert os.path.isdir(git_dir), f"Didn't find the git_dir: {git_dir}"
-    git_dir = ensure_no_slash_suffix(git_dir)
-    if not git_dir.endswith('.git'):
-        warn(f"git_dir doesn't end with `.git`: {git_dir}")
-    command = f'git --git-dir="{git_dir}" --work-tree="{work_tree}" {command}'
-    r = subprocess.check_output(command, shell=True)
+    command_str = _build_git_command(command, work_tree, git_dir)
+    r = subprocess.check_output(command_str, shell=True)
     if isinstance(r, bytes):
         r = r.decode()
     return r.strip()
@@ -62,7 +64,7 @@ def is_standard_lib_path(path):
 
 def standard_lib_module_names(
     is_standard_lib_path=is_standard_lib_path,
-    name_filt=lambda name: not name.startswith('_'),
+    name_filt=lambda name: not name.startswith("_"),
 ):
     return filter(
         name_filt,
@@ -101,7 +103,7 @@ def mk_replacer_from_dict(from_to_dict):
     :return: A replacer function that you can apply to strings to carry out the replacements
     """
 
-    p = re.compile('|'.join(map(r'({})'.format, map(re.escape, from_to_dict.keys()))))
+    p = re.compile("|".join(map(r"({})".format, map(re.escape, from_to_dict.keys()))))
     f = lambda x: from_to_dict[x.group(0)]
 
     def replacer(s):
@@ -135,22 +137,22 @@ def mk_import_root_replacer(from_to_dict):
     :param from_to_dict: A dict of {to_find: to_replace_by,...} pairs
     :return: A replacer function that you can apply to strings to carry out the replacements
 
-    """
+    r"""
     t = dict(
         chain.from_iterable(
             [
-                (f'(?<=from\ ){old}(?=[\.\ ])', f'{new}'),
-                (f'(?<=import\ ){old}(?=[\.\s])', f'{new}'),
+                (f"(?<=from\ ){old}(?=[\.\ ])", f"{new}"),
+                (f"(?<=import\ ){old}(?=[\.\s])", f"{new}"),
             ]
             for old, new in from_to_dict.items()
         )
     )
 
-    p = re.compile('|'.join(map(r'({})'.format, t.keys())))
+    p = re.compile("|".join(map(r"({})".format, t.keys())))
     f = lambda x: from_to_dict[x.group(0)]
 
     def replacer(s):
-        ss = p.sub(f, s + ' ')
+        ss = p.sub(f, s + " ")
         return ss[:-1]
 
     return replacer
@@ -191,19 +193,19 @@ def replace_import_names(
     :return:
     """
 
-    suffix = ''
+    suffix = ""
     if add_comment_at_the_end_of_lines_replaced is False:
-        suffix = ''
+        suffix = ""
     elif add_comment_at_the_end_of_lines_replaced is True:
-        suffix = '# line_was_edited_by_wads'
+        suffix = "# line_was_edited_by_wads"
     elif isinstance(add_comment_at_the_end_of_lines_replaced, str):
         suffix = add_comment_at_the_end_of_lines_replaced
-        if not suffix.startswith('#'):
-            suffix = '# ' + suffix
+        if not suffix.startswith("#"):
+            suffix = "# " + suffix
     else:
         raise TypeError(
             f"Don't know what to do with such a type of add_comment_at_the_end_of_lines_replaced: "
-            f'{add_comment_at_the_end_of_lines_replaced}'
+            f"{add_comment_at_the_end_of_lines_replaced}"
         )
 
     _clog = mk_conditional_logger(condition=verbose, func=print)
@@ -217,7 +219,7 @@ def replace_import_names(
     if source_store == target_store:
         # TODO: Add confirmation (user input) to protect more. Make this an option (so total automatic is possible)
         _clog(
-            'I just wanted you to be aware that you are using the same store for source and target.'
+            "I just wanted you to be aware that you are using the same store for source and target."
             "This means I'm about to overwrite your files!!"
         )
         if dryrun:
@@ -226,19 +228,18 @@ def replace_import_names(
     replacer = replacer_factory(from_to_dict)
 
     if dryrun:
-        replace_prompt = 'will replace'
+        replace_prompt = "will replace"
     else:
-        replace_prompt = '   replacing'
-    with____prompt = '        with'
+        replace_prompt = "   replacing"
+    with____prompt = "        with"
 
     for k, v in source_store.items():
-
         lines_replaced = 0
 
         def gen():
             nonlocal lines_replaced
             for i, line in enumerate(
-                v.split('\n'), 1
+                v.split("\n"), 1
             ):  # TODO: Double traversal. Find online splitter
                 new_line = replacer(line) + suffix
                 yield new_line
@@ -249,10 +250,10 @@ def replace_import_names(
                     clog(
                         verbose or dryrun,
                         print,
-                        f'{k}:{i}:\n{replace_prompt}\t{line}\n{with____prompt}\t{new_line}',
+                        f"{k}:{i}:\n{replace_prompt}\t{line}\n{with____prompt}\t{new_line}",
                     )
 
-        new_v = '\n'.join(gen())
+        new_v = "\n".join(gen())
 
         if not dryrun and lines_replaced > 0:
             target_store[k] = new_v
@@ -261,70 +262,68 @@ def replace_import_names(
 
 
 fc = dict(
-    reset='\033[0m',  # alias for reset_all
-    reset_all='\033[0m',
-    bold='\033[1m',
-    dim='\033[2m',
-    underlined='\033[4m',
-    blink='\033[5m',
-    reverse='\033[7m',
-    hidden='\033[8m',
-    reset_bold='\033[21m',
-    reset_dim='\033[22m',
-    reset_underlined='\033[24m',
-    reset_blink='\033[25m',
-    reset_reverse='\033[27m',
-    reset_hidden='\033[28m',
-    default='\033[39m',
-    black='\033[30m',
-    red='\033[31m',
-    green='\033[32m',
-    yellow='\033[33m',
-    blue='\033[34m',
-    magenta='\033[35m',
-    cyan='\033[36m',
-    gray='\033[37m',
-    dark_gray='\033[90m',
-    dark_red='\033[91m',
-    dark_green='\033[92m',
-    dark_yellow='\033[93m',
-    dark_blue='\033[94m',
-    dark_magenta='\033[95m',
-    dark_cyan='\033[96m',
-    white='\033[97m',
-    background_default='\033[49m',
-    background_black='\033[40m',
-    background_red='\033[41m',
-    background_green='\033[42m',
-    background_yellow='\033[43m',
-    background_blue='\033[44m',
-    background_magenta='\033[45m',
-    background_cyan='\033[46m',
-    background_gray='\033[47m',
-    background_dark_gray='\033[100m',
-    background_dark_red='\033[101m',
-    background_dark_green='\033[102m',
-    background_dark_yellow='\033[103m',
-    background_dark_blue='\033[104m',
-    background_dark_magenta='\033[105m',
-    background_dark_cyan='\033[106m',
-    background_white='\033[107m',
+    reset="\033[0m",  # alias for reset_all
+    reset_all="\033[0m",
+    bold="\033[1m",
+    dim="\033[2m",
+    underlined="\033[4m",
+    blink="\033[5m",
+    reverse="\033[7m",
+    hidden="\033[8m",
+    reset_bold="\033[21m",
+    reset_dim="\033[22m",
+    reset_underlined="\033[24m",
+    reset_blink="\033[25m",
+    reset_reverse="\033[27m",
+    reset_hidden="\033[28m",
+    default="\033[39m",
+    black="\033[30m",
+    red="\033[31m",
+    green="\033[32m",
+    yellow="\033[33m",
+    blue="\033[34m",
+    magenta="\033[35m",
+    cyan="\033[36m",
+    gray="\033[37m",
+    dark_gray="\033[90m",
+    dark_red="\033[91m",
+    dark_green="\033[92m",
+    dark_yellow="\033[93m",
+    dark_blue="\033[94m",
+    dark_magenta="\033[95m",
+    dark_cyan="\033[96m",
+    white="\033[97m",
+    background_default="\033[49m",
+    background_black="\033[40m",
+    background_red="\033[41m",
+    background_green="\033[42m",
+    background_yellow="\033[43m",
+    background_blue="\033[44m",
+    background_magenta="\033[45m",
+    background_cyan="\033[46m",
+    background_gray="\033[47m",
+    background_dark_gray="\033[100m",
+    background_dark_red="\033[101m",
+    background_dark_green="\033[102m",
+    background_dark_yellow="\033[103m",
+    background_dark_blue="\033[104m",
+    background_dark_magenta="\033[105m",
+    background_dark_cyan="\033[106m",
+    background_white="\033[107m",
 )
 
-try:
-    from py2store.sources import DictAttr
+# Make a namespace out of the fc dict
+from types import SimpleNamespace
 
-    fc = DictAttr(**fc)
-except ModuleNotFoundError:
-    pass  # DictAttr is convenient, but not necessary
+fcc = SimpleNamespace(**fc)
 
 
 def highlight(
     string,
-    effect=fc['reverse'],
-    beg_mark='[[',
-    end_mark=']]',
-    end_effect=fc['reset_all'],
+    effect=fc["reverse"],
+    beg_mark="[[",
+    end_mark="]]",
+    end_effect=fc["reset_all"],
 ):
     r"""Interprets a string's highlight markers to be able to make highlights in the string.
 
@@ -364,3 +363,92 @@ def highlight(
     :return:
     """
     return string.replace(beg_mark, effect).replace(end_mark, end_effect)
+
+
+# ------------------------------------------------------------------------------------ #
+# A function to import objects from modules when we want to have a backup in case the
+# object is not found in the first module.
+
+
+def find_obj(*module_and_obj_names):
+    """Find an object from specified modules, under specified names.
+
+    This function searches for a specified object in a list of specified modules.
+    It first tries to import the object from the first module specified, then the
+    second, and so on, until it finds the object. If the object is not found in any
+    of the specified modules, an ImportError is raised.
+
+    Args:
+        *module_and_obj_names: A list of pairs of module names and object names.
+            The first module specified is searched first, then the second, and so on,
+            until the object is found. Each module and object pair is specified as a
+            tuple containing two strings. The first string is the module name, and the
+            second string is the object name. Alternatively, the module and object pair
+            can be specified as a single string containing two space-separated strings,
+            where the first string is the module name and the second string is the
+            object name.
+
+    Returns:
+        The imported object.
+
+    Raises:
+        ImportError: If the object cannot be found in any of the specified modules.
+
+    >>> files = find_obj('importlib.resources files', 'importlib_resources files')
+    >>> callable(files)
+    True
+    >>> find_obj(
+    ...     'importlib no_such_obj', 'no_such_pkg x', ['wave.no_such_module', 'y']
+    ... ) # doctest: +NORMALIZE_WHITESPACE
+    Traceback (most recent call last):
+    ...
+    ImportError: All of these import attempts failed:
+        from importlib import no_such_obj
+        from no_such_pkg import x
+        from wave.no_such_module import y
+
+    See discussion: https://github.com/i2mint/wads/discussions/10.
+    """
+    module_and_obj_names = list(map(_ensure_pair, module_and_obj_names))
+    for module_name, obj_name in module_and_obj_names:
+        try:
+            return import_obj(module_name, obj_name)
+        except (ImportError, ModuleNotFoundError, AttributeError):
+            continue
+    from_import_statements = "\n\t" + "\n\t".join(
+        map("from {} import {}".format, *zip(*module_and_obj_names))
+    )
+    raise ImportError(f"All of these import attempts failed:{from_import_statements}")
+
+
+def import_obj(module_name: str, obj_name: str):
+    """Import an object from a specified module.
+
+    Args:
+        from_ (str): The name of the module to import from.
+        obj_name (str): The name of the object to import.
+
+    Returns:
+        The imported object.
+
+    Raises:
+        ImportError: If the module or object cannot be imported.
+        AttributeError: If the object does not exist in the module.
+
+    >>> spec_finder = import_obj('importlib.util', 'find_spec')
+    >>> callable(spec_finder)
+    True
+    >>> spec_finder.__module__
+    'importlib.util'
+
+    """
+    module = __import__(module_name, fromlist=[obj_name])
+    obj = getattr(module, obj_name)
+    return obj
+
+
+def _ensure_pair(x):
+    if isinstance(x, str):
+        x = x.split()
+    assert len(x) == 2, f"should be a pair of strings: {x}"
+    return x
